@@ -14,21 +14,12 @@ from remotecv.detectors import BaseDetector
 
 class FeatureDetector(BaseDetector):
 
-    def detect(self, width, height, mode, img_data):
-        sz = (width, height)
-        image = cv.CreateImageHeader(sz, cv.IPL_DEPTH_8U, 3)
-        cv.SetData(image, img_data)
-
-        gray_image = cv.CreateImage(sz, 8, 1);
-        convert_mode = getattr(cv, 'CV_%s2GRAY' % mode)
-        cv.CvtColor(image, gray_image, convert_mode)
-        image = gray_image
-        rows = sz[0]
-        cols = sz[1]
+    def detect(self, image):
+        rows, cols = image.size
 
         eig_image = cv.CreateMat(rows, cols, cv.CV_32FC1)
         temp_image = cv.CreateMat(rows, cols, cv.CV_32FC1)
-        points = cv.GoodFeaturesToTrack(image, eig_image, temp_image, 20, 0.04, 1.0, useHarris = False)
+        points = cv.GoodFeaturesToTrack(image.image, eig_image, temp_image, 20, 0.04, 1.0, useHarris = False)
 
         if points:
             return [[x, y, 1, 1] for x, y in points]
